@@ -17,6 +17,27 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+/*
+ * Support for 
+     public void setBounds( Rectangle bounds )
+     public void setBounds( int top_, int left_, int bottom_, int right_) 
+     public void setBounds(Point topleft_, Dimension size_)
+
+* Change of
+     protected Container getParent() by 
+     public Container getParent()
+
+* Correct manage of KeysEvents ( Lost and Gained )
+    public void addKeyListener(KeyListener kl_)
+
+* Correct manage of FocusEvents ( Lost and Gained )
+    public void addFocusListener(FocusListener fl_)
+    public void requestFocus() 
+
+ *
+ *
+ */
+
 package charva.awt;
 
 import charva.awt.event.*;
@@ -25,10 +46,16 @@ import java.lang.ref.WeakReference;
 import java.util.Enumeration;
 import java.util.Vector;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 /**
  * Component is the abstract superclass of all the other CHARVA widgets.
  */
 public abstract class Component {
+
+    private static final Log LOG = LogFactory.getLog(Component.class);
+
     /**
      * Constructor
      */
@@ -155,6 +182,18 @@ public abstract class Component {
         return new Rectangle(_origin, getSize());
     }
 
+    public void setBounds( Rectangle bounds ) {
+        setLocation(bounds.getLeft(), bounds.getTop());
+    }
+
+    public void setBounds( int top_, int left_, int bottom_, int right_) {
+        setLocation(left_, top_ );
+    }
+
+    public void setBounds(Point topleft_, Dimension size_) {
+        setLocation(topleft_ );
+    }
+
     /**
      * Checks whether this component "contains" the specified point,
      * where the point's x and y coordinates are defined to be relative
@@ -192,7 +231,7 @@ public abstract class Component {
      * Get the parent container of this component. Can return null if the
      * component has no parent.
      */
-    protected Container getParent() {
+    public Container getParent() {
         if (_parent == null)
             return null;
 
@@ -207,7 +246,9 @@ public abstract class Component {
     public void addKeyListener(KeyListener kl_) {
         if (_keyListeners == null)
             _keyListeners = new Vector();
-        _keyListeners.add(kl_);
+        if ( ! _keyListeners.contains(kl_)) {
+           _keyListeners.add(kl_);
+        }
     }
 
     /**
@@ -216,7 +257,9 @@ public abstract class Component {
     public void addFocusListener(FocusListener fl_) {
         if (_focusListeners == null)
             _focusListeners = new Vector();
-        _focusListeners.add(fl_);
+        if ( ! _focusListeners.contains(fl_)) {
+            _focusListeners.add(fl_);
+        }
     }
 
     /**
@@ -292,6 +335,7 @@ public abstract class Component {
      * for this component.
      */
     public void processFocusEvent(FocusEvent fe_) {
+        LOG.debug( "processFocusEvent:" + this.toString() + " ev:" + fe_.toString() );
         if (_focusListeners != null) {
             for (Enumeration e = _focusListeners.elements();
                  e.hasMoreElements();) {
@@ -316,7 +360,7 @@ public abstract class Component {
             return (Window) this;
 
         for (ancestor = getParent();
-             (ancestor instanceof Window) == false;
+             !(ancestor instanceof Window);
              ancestor = nextancestor) {
 
             if (ancestor == null)
@@ -334,20 +378,48 @@ public abstract class Component {
      * FOCUS_GAINED event when the component gains the keyboard focus.
      */
     public void requestFocus() {
-
+        boolean temporary = false;
         /* Generate the FOCUS_GAINED only if the component does not
          * already have the focus.
          */
         Window ancestor = getAncestorWindow();
         Component currentFocus = ancestor.getCurrentFocus();
-        if (currentFocus != this) {
+        Window sourcewin = Toolkit.getDefaultToolkit().getTopWindow();
+        Component currentFocusX = sourcewin.getCurrentFocus();
+     /*
+        LOG.debug( "requestFocus1: " + toString() );
+        LOG.debug( "currentFocus2: " + currentFocusX.toString() );
+      */
+        if (currentFocus != this ||
+            ( currentFocusX == this && ! _hadFocus )) {
+            _hadFocus = true;
             EventQueue evtQueue =
                     Toolkit.getDefaultToolkit().getSystemEventQueue();
-            FocusEvent evt = new FocusEvent(AWTEvent.FOCUS_LOST, currentFocus);
-            evtQueue.postEvent(evt);
+            FocusEvent evt;
+            FocusEvent lastEvt = Toolkit.getDefaultToolkit().getLastFocusEvent();
 
-            evt = new FocusEvent(AWTEvent.FOCUS_GAINED, this);
+            if ( lastEvt != null ) {
+                currentFocus = (Component)lastEvt.getSource();
+                if ( currentFocus != null &&
+                     currentFocus.getAncestorWindow() != null &&
+                     currentFocus.getAncestorWindow().isEnabled() &&
+                     currentFocus.getAncestorWindow() != ancestor ) {
+                     temporary = true;
+                }
+                else {
+                     temporary = false;
+                }
+                evt = new FocusEvent(AWTEvent.FOCUS_LOST, currentFocus, temporary, this);
+                evtQueue.postEvent(evt);
+                //System.err.println( "DisparoFocusLost: " + currentFocus.toString() + " Window:" + currentFocus.getAncestorWindow().toString() + " //" + currentFocus.getAncestorWindow().isValid() );
+            }
+            else {
+                currentFocus = null;
+            }
+
+            evt = new FocusEvent(AWTEvent.FOCUS_GAINED, this,  temporary, currentFocus);
             evtQueue.postEvent(evt);
+            //System.err.println( "DisparoFocusGained: " + this.toString() + " Window:" + ancestor.toString() );
 
 //	    if (getParent() != null)
             getParent().setFocus(this);
@@ -517,7 +589,7 @@ public abstract class Component {
      * (this is done by posting a RepaintEvent onto the system queue).
      */
     public void repaint() {
-        if (isDisplayed() == false)
+        if (!isDisplayed())
             return;
 
         PaintEvent evt = new PaintEvent(this, getBounds());
@@ -586,6 +658,8 @@ public abstract class Component {
     //====================================================================
     // INSTANCE VARIABLES
 
+    private boolean _hadFocus = false;
+
     /**
      * The coordinates of the top-left corner of the component, relative to
      * its parent container.
