@@ -24,20 +24,19 @@ package charva.awt;
  * illegal state for the requested operation.
  */
 public class IllegalComponentStateException
-    extends RuntimeException
-{
-    /** Construct an IllegalComponentStateException.
+        extends RuntimeException {
+    /**
+     * Construct an IllegalComponentStateException.
      */
-    public IllegalComponentStateException()
-    {
-	super();
+    public IllegalComponentStateException() {
+        super();
     }
 
-    /** Construct an IllegalComponentStateException with the specified
+    /**
+     * Construct an IllegalComponentStateException with the specified
      * message.
      */
-    public IllegalComponentStateException(String msg)
-    {
-	super(msg);
+    public IllegalComponentStateException(String msg) {
+        super(msg);
     }
 }
