@@ -22,28 +22,26 @@ package charva.awt;
 /**
  * This (package-private) class encapsulates information about a mouse event.
  */
-class MouseEventInfo
-{
+class MouseEventInfo {
     /**
      * Construct an event with the specified source and ID.
      */
-    public MouseEventInfo(int button_, int x_, int y_)
-    {
-	button = button_;
-	x = x_;
-	y = y_;
+    public MouseEventInfo(int button_, int x_, int y_) {
+        button = button_;
+        x = x_;
+        y = y_;
     }
 
-    public int getButton() { 
-	return button; 
+    public int getButton() {
+        return button;
     }
 
     public int getX() {
-	return x;
+        return x;
     }
 
     public int getY() {
-	return y;
+        return y;
     }
 
     //====================================================================
