@@ -25,16 +25,13 @@ package charva.awt;
  * when it finds the requested capability but it is of the wrong
  * type).
  */
-public class TerminfoCapabilityException
-    extends Exception
-{
-    public TerminfoCapabilityException()
-    {
-	super();
+public class TerminfoCapabilityException extends Exception {
+    
+    public TerminfoCapabilityException() {
+        super();
     }
 
-    public TerminfoCapabilityException(String msg)
-    {
-	super(msg);
+    public TerminfoCapabilityException(String msg) {
+        super(msg);
     }
 }
