@@ -34,12 +34,16 @@ import charva.awt.event.AWTEvent;
 import charva.awt.event.GarbageCollectionEvent;
 import charva.awt.event.KeyEvent;
 import charva.awt.event.MouseEvent;
+import charva.awt.event.FocusEvent;
 
 import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.PrintStream;
 import java.util.Vector;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 /**
  * The Toolkit class provides the interface to the "ncurses" library
  * functions. Exceptions and error messages are reported to the
@@ -49,7 +53,16 @@ import java.util.Vector;
  * these defaults can be modified by changing the static variables
  * _defaultForeground and _defaultBackground.
  */
+
+/**
+ * Correct manage of FocusEvents
+    public FocusEvent getLastFocusEvent()
+    protected void setLastFocusEvent(FocusEvent ev_ )
+ */
 public class Toolkit {
+
+    private static final Log LOG = LogFactory.getLog(Toolkit.class);
+
     /**
      * The constructor can only be called by the getDefaultToolkit() method,
      * making this an example of the Singleton pattern.
@@ -145,14 +158,22 @@ public class Toolkit {
      */
     public void fireKeystroke(int key_, Component source_) {
         int id;
-        if (key_ > 255 || key_ < ' ')
-            id = AWTEvent.KEY_PRESSED;
-        else
+        if (Toolkit.isActionKey(key_))
             id = AWTEvent.KEY_TYPED;
+        else
+            id = AWTEvent.KEY_PRESSED;
 
         _evtQueue.postEvent(new KeyEvent(key_, id, source_));
     }
 
+    public FocusEvent getLastFocusEvent() {
+        return _lastFocusEvent;
+    }
+
+    protected void setLastFocusEvent(FocusEvent ev_ ) {
+        _lastFocusEvent = ev_;
+    }
+
     /**
      * Processes the mouse-click specified by mouse_info.
      * Note that we disable mouse-click resolution in the ncurses library
@@ -239,8 +260,6 @@ public class Toolkit {
          * THIS HAS CHANGED! readKey returns -1 if there was no key to read.
          */
         if (key == -1) {
-            //System.err.println("end of file on keyboard input");
-            //System.exit(-1);
             return;
         }
 
@@ -770,11 +789,59 @@ public class Toolkit {
      */
     private static native int getACSchar(int offset_);
 
+ /**
+     * Returns true if the key code is greater than 255, indicating
+     * that it is a function key.
+     */
+    //public boolean isActionKey() { return (_key >= 256); }
+    public static boolean isActionKey( int _key )
+    {
+        boolean value = false;
+        if ( _key == charva.awt.event.KeyEvent.VK_ESCAPE ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_DOWN ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_UP ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_LEFT ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_RIGHT ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_HOME ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_BACK_SPACE ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F1 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F2 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F3 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F4 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F5 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F6 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F7 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F8 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F9 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F10 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F11 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F12 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F13 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F14 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F15 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F16 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F17 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F18 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F19 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_F20 ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_DELETE ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_INSERT ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_PAGE_DOWN ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_PAGE_UP ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_ENTER ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_BACK_TAB ) value=true;
+        if ( _key == charva.awt.event.KeyEvent.VK_END ) value=true;
+
+        return (value);
+    }
+
     //====================================================================
     // INSTANCE VARIABLES
 
     private static Toolkit _instance = null;
 
+    private static FocusEvent _lastFocusEvent = null;
+
     /**
      * A list of visible Windows.  The first in the list is at the bottom, the
      * last is on top.
@@ -820,7 +887,7 @@ public class Toolkit {
             try {
                 _scriptPrintStream = new PrintStream(new FileOutputStream(scriptfilename));
             } catch (FileNotFoundException ef) {
-                System.err.println("Cannot open script file \"" +
+                LOG.warn("Cannot open script file \"" +
                         scriptfilename + "\" for writing");
                 System.exit(1);
             }
