@@ -21,12 +21,13 @@ package charva.awt;
 
 import charva.awt.event.*;
 
-import java.io.BufferedReader;
-import java.io.FileNotFoundException;
-import java.io.FileReader;
+import java.io.File;
 import java.util.Enumeration;
 import java.util.Vector;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 /**
  * The Window class represents a "toplevel" window with
  * no decorative frame. The window is initially invisible; you must use
@@ -35,6 +36,9 @@ import java.util.Vector;
 public class Window
         extends Container
         implements Runnable {
+
+    private static final Log LOG = LogFactory.getLog(Window.class);
+
     public Window(Window owner_) {
         _owner = owner_;
         init();
@@ -126,7 +130,7 @@ public class Window
     public void show() {
 
         if (_visible)
-            return;	// This window is already visible.
+            return;    // This window is already visible.
 
         _visible = true;
         _term.addWindow(this);
@@ -135,7 +139,7 @@ public class Window
          * the contained components (i.e. children) and their descendants,
          * and in the process will set the valid flag of all descendants.
          */
-        super.doLayout();	// call method in Container superclass
+        super.doLayout();    // call method in Container superclass
 
         this.adjustLocation();   // ensure it fits inside the screen
 
@@ -193,7 +197,7 @@ public class Window
                      */
                     processEvent((AWTEvent) evt);
                 }
-            }	// end FOR loop
+            }    // end FOR loop
         } catch (Exception e) {
             e.printStackTrace();
             System.exit(1);
@@ -285,7 +289,7 @@ public class Window
                         window = (Window) winlist.elementAt(i);
                         window.draw();
                     }
-                    if (window != null)	    // (there may be no windows left)
+                    if (window != null)        // (there may be no windows left)
                         window.requestFocus();
                 }
 
@@ -301,7 +305,7 @@ public class Window
                 if (window != null)
                     SyncQueue.getInstance().postEvent(new SyncEvent(window));
             }
-        }	// end if WindowEvent
+        }    // end if WindowEvent
         else if (evt_ instanceof GarbageCollectionEvent) {
             SyncQueue.getInstance().postEvent(evt_);
         } else if (evt_ instanceof InvocationEvent) {
@@ -321,8 +325,8 @@ public class Window
     public void hide() {
 
         if (!_visible) {
-            System.err.println("Trying to hide window " + this + " that is already hidden!");
-            return;	// This window is already hidden.
+            LOG.warn("Trying to hide window " + this + " that is already hidden!");
+            return;    // This window is already hidden.
         }
 
         _visible = false;
@@ -376,26 +380,23 @@ public class Window
     }
 
     public void debug(int level_) {
-        System.err.println("Window origin=" + _origin +
-                " size=" + _size);
+        LOG.debug("Window origin=" + _origin + " size=" + _size);
         super.debug(1);
     }
 
     private void startPlayback() {
-        String scriptfilename = null;
-        BufferedReader scriptReader = null;
-        if ((scriptfilename = System.getProperty("charva.script.playback")) == null)
+        String scriptfilename;
+        if ((scriptfilename = System.getProperty("charva.script.playbackFile")) == null)
             return;
 
-        try {
-            scriptReader = new BufferedReader(new FileReader(scriptfilename));
-        } catch (FileNotFoundException ef) {
-            System.err.println("Cannot open script file \"" +
-                    scriptfilename + "\" for reading");
+        File scriptFile = new File(scriptfilename);
+        if (!scriptFile.canRead()) {
+            LOG.warn("Cannot read script tile \"" + scriptfilename + "\"");
             return;
         }
 
-        PlaybackThread thr = new PlaybackThread(scriptReader);
+
+        PlaybackThread thr = new PlaybackThread(scriptFile);
         thr.setDaemon(true);
         thr.setName("playback thread");
         thr.start();
