@@ -26,9 +26,9 @@ import charva.awt.Insets;
  * Interface describing an object capable of rendering a border
  * around the edges of a component.
  */
-public interface Border
-{
-    /** Returns the insets of the border.
+public interface Border {
+    /**
+     * Returns the insets of the border.
      */
     public Insets getBorderInsets(Component component_);
 
@@ -37,5 +37,5 @@ public interface Border
      * position and size.
      */
     public void paintBorder(Component component_,
-	int colorpair_, int x_, int y_, int width_, int height_);
+                            int colorpair_, int x_, int y_, int width_, int height_);
 }
